# SHCAi Client 
![build](https://github.com/ihealth-group/shcai-cli/actions/workflows/ci-cd.yml/badge.svg?event=push) 
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
[![python](https://img.shields.io/badge/Python-3.9-3776AB.svg?style=flat&logo=python&logoColor=white)](https://www.python.org)

### Introdução